==> v11.1.2.zip: brewman/overlord/src/app/employee-benefits/employee-benefits-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';

import { EmployeeBenefitsResolver } from './employee-benefits-resolver.service';
import { EmployeeBenefitsComponent } from './employee-benefits.component';

const employeeBenefitsRoutes: Routes = [
  {
    path: '',
    component: EmployeeBenefitsComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'employee-benefit',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(EmployeeBenefitsResolver).resolve(route),
    },
    runGuardsAndResolvers: 'always',
  },
  {
    path: ':id',
    component: EmployeeBenefitsComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'employee-benefit',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(EmployeeBenefitsResolver).resolve(route),
    },
    runGuardsAndResolvers: 'always',
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(employeeBenefitsRoutes)],
  exports: [RouterModule],
  providers: [EmployeeBenefitsResolver],
})
export class EmployeeBenefitsRoutingModule {}

==> v11.6.0.zip: brewman/overlord/src/app/employee-benefits/employee-benefits-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';

import { EmployeeBenefitsResolver } from './employee-benefits-resolver.service';
import { EmployeeBenefitsComponent } from './employee-benefits.component';

const employeeBenefitsRoutes: Routes = [
  {
    path: '',
    component: EmployeeBenefitsComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'employee-benefit',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(EmployeeBenefitsResolver).resolve(route),
    },
    runGuardsAndResolvers: 'always',
  },
  {
    path: ':id',
    component: EmployeeBenefitsComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'employee-benefit',
    },
    resolve: {
      voucher: (route: ActivatedRouteSnapshot) => inject(EmployeeBenefitsResolver).resolve(route),
    },
    runGuardsAndResolvers: 'always',
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(employeeBenefitsRoutes)],
  exports: [RouterModule],
  providers: [EmployeeBenefitsResolver],
})
export class EmployeeBenefitsRoutingModule {}
